# Command related errors.
ACTION_ABORTED = "The action was aborted."
ALIAS_NOT_FOUND = "The alias '{0}' does not exist in the current tomb."
EMPTY_TOMB = "Nothing but crumbled bones and dust..."

# Application specific errors.
INVALID_COLOR = "The desired color is not available: '{0}'."
