# Configuration naming.
CONFIG_DIR_NAME = ".catacomb"
CONFIG_FILE_NAME = ".catacomb_config"

# Settings to override on the context object.
CONTEXT_SETTINGS = {
    "help_option_names": ["-h", "--help"]
}
